diff --git a/src/pkg/exp/template/html/context.go b/src/pkg/exp/template/html/context.go
index f7802d04b3..57d44938ca 100644
--- a/src/pkg/exp/template/html/context.go
+++ b/src/pkg/exp/template/html/context.go
@@ -89,8 +89,8 @@ const (
// stateBeforeValue occurs after the equals sign but before the value.
// It occurs between the ^'s in ` name =^ ^value`.
stateBeforeValue
- // stateComment occurs inside an .
- stateComment
+ // stateHTMLCmt occurs inside an .
+ stateHTMLCmt
// stateRCDATA occurs inside an RCDATA element (